declare("tgft_utils", {version = "T2.02"})
-- TGFT Price data Collector and reporter
--	Lisa201

require("iuplua")
require("iupluacontrols")
dofile("tgftd_http.lua")
dofile("systems.lua")
dofile("json.lua")
tgft_utils.ui = dofile'ui.lua'

tgft_utils.Network = 0
TGFT_DeBug = false
tgft_utils.passwd = nil
tgft_utils.username = nil
tgft_utils.unload = false
tgft_utils.TurboOn = false
tgft_utils.nodeid = 0
tgft_utils.objectid = 0
tgft_utils.keys = {}
tgft_utils.stations = {}
tgft_utils.warned = false
tgft_utils.watchdent = true
tgft_utils.LastSector = "None"
tgft_utils.Timer = Timer()

-------------------------------------------------------
-- Process server data received event
-------------------------------------------------------
function tgft_utils.ServerDataEvent(_,data)
local v = data[1][1]
if TGFT_DeBug then print("got data from script: "..v) end

if v == "liststations" then tgft_utils.stations = data[2];
elseif v == "c" then print("see")
elseif v == "h" then print("aych")
end

end

-------------------------------------------------------
-- CallBack from server requests.
-------------------------------------------------------
function tgft_utils.GetServerData(script)
if TGFT_DeBug then print("Running script:"..script..".php") end
urlopen('http://www.tgft.org/vendetta/'..script..'.php', 'POST',
function (not_ok, header, data)
	if not_ok then
		tgft_utils.msg(LK_White,not_ok)
	else
		if header.status == 200 then --Process what came back
			tgft_utils.SrvHead = json.decode(data)
			ProcessEvent("TGFT_SERVER_DATA", tgft_utils.SrvHead)
		elseif header.status then
			tgft_utils.msg(LK_White,"ERROR9: HTTP Error "..header.status.."   Script:"..script)
		end
	end
end
,{username=tgft_utils.username, passwd=tgft_utils.passwd, app=tgft_utils.version})
end


-------------------------------------------------------
-- create random string for password
-------------------------------------------------------
function tgft_utils.RandomString(length)
if length < 1 then return nil end
local valChars = "1234567890abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ"
length = length or 1
local array = ""
for i = 1,length do
	local A = math.random(#valChars)
	array = array..string.sub(valChars,A,A)
end
return array
end

-------------------------------------------------------------	
-- Toggle Turbo on and off
-------------------------------------------------------------	
function turbotoggle()
if tgft_utils.TurboOn then
      gkinterface.GKProcessCommand('+turbo 1')
      gkinterface.GKProcessCommand('+turbo 0')
else
      gkinterface.GKProcessCommand('+turbo 0')
      gkinterface.GKProcessCommand('+turbo 1')
 end
	tgft_utils.TurboOn = not tgft_utils.TurboOn
end

-------------------------------------------------------------	
-- Toggle debug on and off
-------------------------------------------------------------	
function debugtoggle()
	TGFT_DeBug = not TGFT_DeBug
	if TGFT_DeBug then print("debug on") else print("debug off") end
end

-------------------------------------------------------------	
-- Launch from the ship
-------------------------------------------------------------	
function tgft_utils.launch()
RequestLaunch() 
end

-------------------------------------------------------
-- Get Keys in your keychain
-------------------------------------------------------
function tgft_utils.Get_Keychain()
if TGFT_DeBug then print("tgft_utils is calling the get key routine.") end
tgft_utils.keys = {}
for v = 1, GetNumKeysInKeychain(), 1 do
		local keyid, description, owner, timestamp, access, possessors, active = GetKeyInfo(tonumber(v))
		local key_data = {}
		if active then -- Only active keys have possessor tables...
			Keychain.list(keyid, 
				function(isError, message)
				if (isError) then
					print("KEY ERROR:")
				else
					keyid, description, owner, timestamp, access, possessors, active = GetKeyInfo(tonumber(v))
				end
			end)
			local key_data = {ID = keyid, DESC = description, OWN = owner, ACTIVE = active, ACCESS = access, POSS = possessors }
			table.insert(tgft_utils.keys,key_data)
		end
	end
end

-------------------------------------------------------
-- Get a keys index number 
-------------------------------------------------------
function tgft_utils.GetKeyIndex(x)
	for i = 1, GetNumKeysInKeychain(), 1 do 
		local keyid, description, owner, timestamp, access, possessors, active = GetKeyInfo(tonumber(i))
		if (tonumber(keyid) == tonumber(x)) then return i end
	end
return -1 -- Not found in the list 
end

-------------------------------------------------------
-- Verify Key when you enter systems 
-------------------------------------------------------
function tgft_utils.VerifyDestination()
	local destsector = NavRoute.GetNextHop()
	if not destsector then return end
  	if TGFT_DeBug then print("2 Destination Sector is:"..destsector) end
	local stationname = "None"
	if destsector==4019 then stationname = "Pelatus Mining Station" end
	if destsector==4317 then stationname = "Bractus IX Planetary Outpost" end
	if destsector==5753 then stationname = "CONQUERABLE STATION" end
	tgft_utils.Sector_Verified()
	if stationname == "None" then return end -- Normal sectors... just return
	
	for i = 1, #tgft_utils.keys, 1 do 
		local keyid, description, owner, timestamp, access, possessors, active = 
			GetKeyInfo(tonumber(tgft_utils.GetKeyIndex(tgft_utils.keys[i]["ID"])))
		if access then 
			for j = 1, # access, 1 do 
				if (access[j][1].name==stationname) then
					if (access[j][2].candock) and (access[j][2].iff)then return end
				end
			end
		end
	end
	print("\127ff1010-- WARNING -- Key is NOT VALID for: "..stationname)
end 

-------------------------------------------------------
-- Verify faction standing before jumping to systems
-------------------------------------------------------
function tgft_utils.Sector_Verified()
	local destsector = NavRoute.GetNextHop()
  	if TGFT_DeBug then print("1 Destination Sector is:"..destsector) end
	local systemid = GetSystemID(destsector)
  	if TGFT_DeBug then print("SystemID is:"..systemid) end
	local faction = tgft_utils.System_Names[systemid][3]
  	if TGFT_DeBug then print("Local Factin is:"..faction) end
  	if TGFT_DeBug then print("Number of stations loaded:"..#tgft_utils.stations) end
	
	for i = 1, #tgft_utils.stations, 1 do
		if (tonumber(tgft_utils.stations[i][1]) == destsector) then
			faction = tonumber(tgft_utils.stations[i][2])
			break;
		end
	end
	local destfaction = GetPlayerFactionStanding(faction, GetCharacterID()) / 32.768 -1000
	if destfaction < -600 then
		print("\127ff1010-- WARNING -- Faction Standing at Destination: "..math.floor(destfaction))
	elseif destfaction < -590 then
		print("\127FFFF00-- CAUTION -- Check Faction Standing.  Low at Destination! "..math.floor(destfaction))
	end
end

-------------------------------------------------------
-- Saw a player in space
-------------------------------------------------------
function tgft_utils.SawPlayer(event, data)
	if not tgft_utils.Network then return end
	if not data then return end
 	local characteris = GetPlayerName(data)
 	local hischarid = data
 	if characteris == GetPlayerName(GetCharacterID()) then return end
  	local isNPC = (string.sub( characteris, 1, 1) == "*") or (string.match(characteris, "reading transponder"))
  	if isNPC then return end --Don't log bots...
 	local hisship = GetPrimaryShipNameOfPlayer(data) or "NO Ship"
 	local hisguild = GetGuildTag(data)
  	if TGFT_DeBug then print("SawPlayer Event:"..event) end
 	if TGFT_DeBug then print("Spotted: "..characteris.."   Ship:"..hisship) end
 	if (hisship == "NO Ship" ) then return end -- Don't send spots with no ships.
 	local whereat = ShortLocationStr(GetCurrentSectorid())
	if TGFT_DeBug then print("Sending player spot: "..characteris.."  Guild: "..hisguild.." Ship: "..hisship.."  CharID: "..hischarid) end
	local mydata = {}
	table.insert(mydata,characteris)
	table.insert(mydata,hisguild)
	table.insert(mydata,hischarid)
	table.insert(mydata,whereat)
	table.insert(mydata,GetPlayerName(GetCharacterID()))
	table.insert(mydata,hisship)
	table.insert(mydata,tgft_utils.passwd)
	local senddata = json.encode( mydata )
	urlopen('http://www.tgft.org/vendetta/playerspot3.php', 'POST',tgft_utils.Server_Callback , {username=tgft_utils.username, passwd=tgft_utils.passwd, app=tgft_utils.version, data=senddata})
 end

-------------------------------------------------------
-- Last Seen data 
-------------------------------------------------------
function tgft_utils.Lastseen(_, data)
if not data then return end
urlopen('http://www.tgft.org/vendetta/lastseenplayer.php', 'GET',tgft_utils.Server_Callback, {username=tgft_utils.username, passwd=tgft_utils.passwd, app=tgft_utils.version, name=data[1]})
if TGFT_DeBug then print("Lastseenplayer called") end
end

-------------------------------------------------------
-- Alt Finder
-------------------------------------------------------
function tgft_utils.Altfinder(_, data)
	if not tgft_utils.Network then print("\127ff1010Networking is off.. use /tgftnet. ") return end
if not data then return end
if TGFT_DeBug then print("Altfinder called") end
local senddata = json.encode( data )
urlopen('http://www.tgft.org/vendetta/altfinder.php', 'GET',tgft_utils.Server_Callback, {username=tgft_utils.username, passwd=tgft_utils.passwd, app=tgft_utils.version, data=senddata})
end

LisaHeader={}
-------------------------------------------------------
-- Lastseen Server Call back function 
-------------------------------------------------------
function tgft_utils.Server_Callback_LastseenUI(not_ok, header, tgft_utils_page)
	if TGFT_DeBug then print("LastseenUI Callback Fuction...") end
	local tgft_utils_srvdata	= {}
	LisaHeader=header
	if not_ok then
		tgft_utils.msg(tgft_utils_White,"ERROR1: "..not_ok)
	else
		if header.status == 200 then --Process what came back
		if TGFT_DeBug then print("LastseenUI Fuction...") end
		local temp = string.gsub(tgft_utils_page,"[\r\n]","")
		else
			if TGFT_DeBug then print("Header Status:"..header.status) end
			if header.status then
				tgft_utils.msg(tgft_utils_White,"ERROR2: Data Collector HTTP Error "..header.status)
			end
		end --Process what came back
	end
end

-------------------------------------------------------
-- Lookup Item Low System  
-------------------------------------------------------
function tgft_utils.LookupItemLowSystem(_, data)
if not tgft_utils.Network then print("\127ff1010Networking is off.. use /tgftnet. ") return end
if not data then return end
urlopen('http://www.tgft.org/vendetta/lookupitemlowsystem.php', 'GET',tgft_utils.Server_Callback, {username=tgft_utils.username, passwd=tgft_utils.passwd, app=tgft_utils.version, name=data[1],systemname=data[2]})
if TGFT_DeBug then print("LookupStation called") end
end

-------------------------------------------------------
-- Lookup Item High System  
-------------------------------------------------------
function tgft_utils.LookupItemHighSystem(_, data)
if not tgft_utils.Network then print("\127ff1010Networking is off.. use /tgftnet. ") return end
if not data then return end
urlopen('http://www.tgft.org/vendetta/lookupitemhighsystem.php', 'GET',tgft_utils.Server_Callback, {username=tgft_utils.username, passwd=tgft_utils.passwd, app=tgft_utils.version, name=data[1],systemname=data[2]})
if TGFT_DeBug then print("LookupStation called") end
end

-------------------------------------------------------
-- Server Call back function 
-------------------------------------------------------
function tgft_utils.Server_Callback(not_ok, header, tgft_utils_page)
if TGFT_DeBug then print("TGFT Utils Server_Callback Function...") end
local tgft_utils_srvdata	= {}
  if not_ok then
  	print("\127ffffffERROR1: "..not_ok)
  else
    if header.status == 200 then --Process what came back
  		for token in string.gmatch(tgft_utils_page, "[^\n]+") do --Convert to table
  			if token ~= "\r" then 
				table.insert(tgft_utils_srvdata,token) 
				print("\127ffffff"..token)
			end
		end   
  	else
		if header.status then
    		tgft_utils.msg(tgft_utils_White,"ERROR2: HTTP Error "..header.status)
		end
  	end --Process what came back
   end
end

-------------------------------------------------------
-- TEST Server Call back function NOTE the X
-------------------------------------------------------
function tgft_utils.Server_CallbackX(not_ok, header, tgft_utils_page)
if TGFT_DeBug then print("TGFT Utils Server_Callback Function...") end
local tgft_utils_srvdata	= {}
  if not_ok then
  	print("\127ffffffERROR17: "..not_ok)
  else
    if header.status == 200 then --Process what came back
		local beg = string.find(tgft_utils_page, "[", nil, true)
		local backwards = string.reverse(tgft_utils_page)
		local ending = #tgft_utils_page - string.find(backwards, "]", nil, true) + 1
		print("Beg:"..beg.."  End:"..ending)
  	else
		if header.status then
    		tgft_utils.msg(tgft_utils_White,"ERROR2: HTTP Error "..header.status)
		end
  	end --Process what came back
   end
end

-------------------------------------------------------
-- Sector Data Update 
-------------------------------------------------------
function tgft_utils.SectorUpdate(_, data)
	if not tgft_utils.Network then return end
	local secempty = 0
	local sectorid = GetCurrentSectorid()
	local secname = ShortLocationStr(sectorid)
	if (secname == tgft_utils.LastSector) then return end
	local secstorm = 0
	if IsStormPresent() then
		secstorm = 1
	end
	local botinfo = GetBotSightedInfoForSector(sectorid) or "N/A"
	botinfo = string.gsub(botinfo, "Bots Sighted: ", "") 
	local distance = radar.GetNearestObjectDistance()
	if distance == -1 then 
		secempty = 1
	end
	if TGFT_DeBug then print("Sector Updated.") end
	urlopen('http://www.tgft.org/vendetta/sectordata.php', 'POST',tgft_utils.Server_Callback, {username=tgft_utils.username, passwd=tgft_utils.passwd, app=tgft_utils.version, secempty=secempty,sectorid=sectorid,secname=secname,secstorm=secstorm,botinfo=botinfo,secempty=secempty})
	tgft_utils.LastSector = secname
end

-------------------------------------------------------
-- Search Items   
-------------------------------------------------------
function tgft_utils.SearchItems(_, data)
if not tgft_utils.Network then print("\127ff1010Networking is off.. use /tgftnet. ") return end
if not data then return end
urlopen('http://www.tgft.org/vendetta/searchitems.php', 'GET',tgft_utils.Server_Callback, {username=tgft_utils.username, passwd=tgft_utils.passwd, app=tgft_utils.version, name=data[1]})
if TGFT_DeBug then print("SearchItem called") end
end

-------------------------------------------------------
-- Lookup Item Low Price   
-------------------------------------------------------
function tgft_utils.LookupItemLow(_, data)
if not tgft_utils.Network then print("\127ff1010Networking is off.. use /tgftnet. ") return end
if not data then return end
urlopen('http://www.tgft.org/vendetta/lookupitemlow.php', 'GET',tgft_utils.Server_Callback, {username=tgft_utils.username, passwd=tgft_utils.passwd, app=tgft_utils.version, name=data[1]})
if TGFT_DeBug then print("LookupItemLow called") end
end

-------------------------------------------------------
-- Lookup Item High Price   
-------------------------------------------------------
function tgft_utils.LookupItemHigh(_, data)
if not tgft_utils.Network then print("\127ff1010Networking is off.. use /tgftnet. ") return end
if not data then return end
urlopen('http://www.tgft.org/vendetta/lookupitemhigh.php', 'GET',tgft_utils.Server_Callback, {username=tgft_utils.username, passwd=tgft_utils.passwd, app=tgft_utils.version, name=data[1]})
if TGFT_DeBug then print("LookupItemHigh called") end
end

-------------------------------------------------------
-- Lookup Station names and factions  
-------------------------------------------------------
function tgft_utils.Stations(_, data)
if not tgft_utils.Network then print("\127ff1010Networking is off.. use /tgftnet. ") return end
if not data then return end
urlopen('http://www.tgft.org/vendetta/stations.php', 'POST',tgft_utils.Server_Callback, {username=tgft_utils.username, passwd=tgft_utils.passwd, app=tgft_utils.version, data=json.encode(data)})
if TGFT_DeBug then print("Lookup Stations called") end
end

-------------------------------------------------------
-- Lookup Bots  
-------------------------------------------------------
function tgft_utils.SearchBots(_, data)
if not tgft_utils.Network then print("\127ff1010Networking is off.. use /tgftnet. ") return end
if not data then return end
urlopen('http://www.tgft.org/vendetta/searchbots2.php', 'POST',tgft_utils.Server_Callback, {username=tgft_utils.username, passwd=tgft_utils.passwd, app=tgft_utils.version, data=json.encode(data)})
if TGFT_DeBug then print("Lookup Bots called") end
end

-------------------------------------------------------
-- Remove " from item names...
-------------------------------------------------------
function tgft_utils.RemQuote(data)
data = string.gsub(data, '"', '')
return data
end

function verifydata(data)
	local f = assert(loadstring(data))
	return f()
end

-------------------------------------------------------
-- Station Buy Price Update
-------------------------------------------------------
function tgft_utils.BuyUpdate(_, data)
if not tgft_utils.Network then return end
local stationid = GetStationLocation()
local stationsmarket = {}
for _,info in StationSellableInventoryPairs() do 
	local item = {}
	if (info.type ~= nil) then
		local onepcs = GetStationSellableInventoryPriceByID(info.itemid, 1)
		local many = GetStationSellableInventoryPriceByID(info.itemid, 1000000) / 1000000
		local static = 0
		if (onepcs==many) then -- Check for static price...
			static = 1
		end
		table.insert(item, stationid) -- 0
		table.insert(item, info.itemtype) -- 1 Really the ItemID
		local temp = tgft_utils.RemQuote(info.name)
		table.insert(item, temp) -- 2
		table.insert(item, info.type) -- 3
		table.insert(item, info.price) -- 4
		table.insert(item, static) -- 5
		table.insert(stationsmarket, item)		
	end
end
local senddata = json.encode( stationsmarket )
if TGFT_DeBug then print("Stations Buy prices updated! ") end
urlopen('http://www.tgft.org/vendetta/stationbuyprice.php', 'POST',tgft_utils.Server_Callback, {username=tgft_utils.username, passwd=tgft_utils.passwd, data=senddata})
end

-------------------------------------------------------
-- Toggle Networking on and off.
-------------------------------------------------------
function tgft_utils.nettoggle(_, data)
if tgft_utils.Network then
	print("\127ffffffNetworking functions are now OFF")
	gkini.WriteString("TGFT_Util", "Enabled", 0)

else
	print("\127ffffffNetworking functions are now ON")
	gkini.WriteString("TGFT_Util", "Enabled", 1)
end
tgft_utils.Network = not tgft_utils.Network 
end

-------------------------------------------------------
-- Station Update of things you can buy here
-------------------------------------------------------
function tgft_utils.StationUpdate(_, data)
if not tgft_utils.Network then return end
local item = {}
local sectorid = GetCurrentSectorid()
if TGFT_DeBug then print("SectorID:"..sectorid) end
if (GetCurrentStationType() == 1) then return end
local stationid = GetStationLocation()
if TGFT_DeBug then print("StationID:"..stationid) end
local name = GetStationName(stationid)
if TGFT_DeBug then print("Name:"..name) end
local faction = GetStationFaction(stationid)
if TGFT_DeBug then print("Faction:"..faction) end
table.insert(item,sectorid)
table.insert(item,stationid)
table.insert(item,name)
table.insert(item,faction)
item = json.encode( item )
urlopen('http://www.tgft.org/vendetta/stationinfo.php', 'POST',tgft_utils.Server_Callback, {username=tgft_utils.username, passwd=tgft_utils.passwd, app=tgft_utils.version, data=item})
if TGFT_DeBug then print("Station Data Updated.   stationinfo.php") end

local senddata = {}
for i=1, GetNumStationMerch() do 
	item = {}
	local info = GetStationMerchInfo(i)
	info.mass = tonumber(string.match(info.extendeddesc, "Mass: (%d+) kg") or 0)
	table.insert(item, info.itemid)
	table.insert(item, info.mass)
	table.insert(item, info.type)
	table.insert(item, info.volume)
	table.insert(item, info.name)
	table.insert(item, info.price)
	table.insert(item, stationid)
	table.insert(item, 0)
	table.insert(senddata, item)
end

local senddata = json.encode( senddata )
urlopen('http://www.tgft.org/vendetta/stationitems3.php', 'POST',tgft_utils.Server_Callback, {username=tgft_utils.username, passwd=tgft_utils.passwd, app=tgft_utils.version, data=senddata})
if TGFT_DeBug then print("Station Items Sold Updated.   stationitems.php") end
tgft_utils.BuyUpdate(_, data)
end

-------------------------------------------------------
-- Price Update part 2
-------------------------------------------------------
function tgft_utils.PriceUpdate2(_, data)
UnregisterEvent(tgft_utils.BuyUpdate,"STATION_UPDATE_DESIREDITEMS")
print("Prices have been updated.")	
tgft_utils.Timer:SetTimeout(2000,tgft_utils.BuyUpdate)
end

-------------------------------------------------------
-- Price Update
-------------------------------------------------------
function tgft_utils.PriceUpdate(_, data)
if not data then return end
if string.find(data.msg, "sold for a total amount") then
	RegisterEvent(tgft_utils.PriceUpdate2,"STATION_UPDATE_DESIREDITEMS")
	print("Station prices will update in about a minute...")
	end
end

-------------------------------------------------------
-- Find my Trident
-------------------------------------------------------
function tgft_utils.FindDent(_, data)
	local items = {}
	for itemid,v in PlayerInventoryPairs() do
		local itemname = GetInventoryItemName(itemid)
		local stationid = GetInventoryItemLocation(itemid)
		local sectorid = SplitStationID(stationid)
		local itype = GetInventoryItemLongDesc(itemid) 
		if string.find(itype,"Trident Type") then 
			local location = ShortLocationStr(sectorid)
			if (location=="0 @-0") then
				print("-- Active Ship --")
				break
			end
			items = {itype=itype, location=location, itemname=itemname}
			print("\127ffffffYour dent is in: "..location.."   Navigation route set.")
			local location = string.match(location, '(%a+)').." "..string.match(location, '(%a%-%d+)')
			NavRoute.SetFinalDestination(SectorIDFromLocationStr(location))
		end
	end
end

-------------------------------------------------------
-- Add an item to the guild list  
-------------------------------------------------------
function tgft_utils.GuildItem(_, data) -- command, qty, "item name"
if not tgft_utils.Network then print("\127ff1010Networking is off.. use /tgftnet. ") return end
if not data then 
	print("no data")
	return 
	end
local senddata = json.encode( data )
urlopen('http://www.tgft.org/vendetta/guilditem.php', 'POST',tgft_utils.Server_Callback, {username=tgft_utils.username, passwd=tgft_utils.passwd, app=tgft_utils.version, data=senddata})
if TGFT_DeBug then print("GuildItems called") end
end

-------------------------------------------------------
-- Unload cargo, and re-launch on docking event
-------------------------------------------------------
function tgft_utils.Unload2()
local shipinv = GetShipInventory(GetActiveShipID())
local cargolist = shipinv.cargo
local unloadlist = {}
for k,itemid in ipairs(cargolist) do
	local itemquantity = GetInventoryItemQuantity(itemid)
	if itemquantity then 
		table.insert(unloadlist, {itemid=itemid, quantity=itemquantity}) 
	end
end
CheckStorageAndUnloadCargo(unloadlist)
RequestLaunch()
end

--LisaJunk = {}
-------------------------------------------------------
-- Server Call back function 
-------------------------------------------------------
function tgft_utils.Server_CallBack(not_ok, header, tgft_utils_page)
if TGFT_DeBug then print("TGFT Utils Server_Callback Function...") end
local tgft_utils_srvdata	= {}
  if not_ok then
  	print("\127ffffffERROR1: "..not_ok)
  else
    if header.status == 200 then --Process what came back
		print("--->"..LisaJunk.."<---")
		verifydata(LisaJunk)
  	else
		if header.status then
    		tgft_utils.msg(tgft_utils_White,"ERROR6: HTTP Error "..header.status)
		end
  	end --Process what came back
   end
end

-------------------------------------------------------
-- Unload cargo enable disable events
-------------------------------------------------------
function tgft_utils.Unload()
	if (tgft_utils.unload) then
	print("Auto Unload-Launch OFF")
	tgft_utils.unload = not tgft_utils.unload
	UnregisterEvent(tgft_utils.Unload2, "ENTERED_STATION")
	else
	print("Auto Unload-Launch ON")
	tgft_utils.unload = not tgft_utils.unload
	RegisterEvent(tgft_utils.Unload2, "ENTERED_STATION")
	end
end

-------------------------------------------------------
-- Modify Hostile list
-------------------------------------------------------
function tgft_utils.Hostile(_,data)
--if not data then return end
urlopen('http://www.tgft.org/vendetta/hostile.php', 'POST',tgft_utils.Server_Callback, {username=tgft_utils.username, passwd=tgft_utils.passwd, app=tgft_utils.version, data=json.encode(data)})
if TGFT_DeBug then print("HOSTILE called") end
end

-------------------------------------------------------
-- Modify App list
-------------------------------------------------------
function tgft_utils.App(_,data)
--if not data then return end
urlopen('http://www.tgft.org/vendetta/applicants.php', 'POST',tgft_utils.Server_Callback, {username=tgft_utils.username, passwd=tgft_utils.passwd, app=tgft_utils.version, data=json.encode(data)})
if TGFT_DeBug then print("Applicants called") end
end

-------------------------------------------------------
-- Veriify access to server
-------------------------------------------------------
function tgft_utils.verify(_, data)
urlopen('http://www.tgft.org/vendetta/verifydata.php', 'POST',tgft_utils.Server_CallBack, {username=tgft_utils.username, passwd=tgft_utils.passwd, app=tgft_utils.version, data=json.encode(data)})
if TGFT_DeBug then print("Verify called") end
end

-------------------------------------------------------
-- Load list of stations.  Used for NAV
-------------------------------------------------------
function tgft_utils.GetStations()
if not tgft_utils.Network then return end
urlopen('http://www.tgft.org/vendetta/liststations.php', 'POST',
function (not_ok, header, data)
	if TGFT_DeBug then print("Internal liststations Callback Fuction...") end
	if not_ok then
		print("\127ffffffERROR1: "..not_ok)
	else
		if header.status == 200 then --Process what came back
			tgft_utils.stations=json.decode(data)
		else
			if header.status then
				tgft_utils.msg(tgft_utils_White,"ERROR2: HTTP Error "..header.status)
			end
		end --Process what came back
	end
end
,{username=tgft_utils.username, passwd=tgft_utils.passwd, app=tgft_utils.version})
end

-------------------------------------------------------
-- Init
-------------------------------------------------------
function tgft_utils.Connection()
print("Connected...")
end

-------------------------------------------------------
-- Last Seen Data for UI
-------------------------------------------------------
function tgft_utils.LastSeenData(_, data)
if not tgft_utils.Network then print("\127ff1010Networking is off.. use /tgftnet. ") return end
if not data then return end
urlopen('http://www.tgft.org/vendetta/lastseendata.php', 'POST',tgft_utils.Server_CallbackX, {username=tgft_utils.username, passwd=tgft_utils.passwd, app=tgft_utils.version, data=json.encode(data)})
if TGFT_DeBug then print("LastseenData called") end
end

-------------------------------------------------------
-- Save Binds
-------------------------------------------------------
function tgft_utils.BindSave(_, data)
print("\127ffffffSaving current binds....")
gkinterface.GKSaveCfg()
end

-------------------------------------------------------
-- Test function
-------------------------------------------------------
function tgft_utils.test(_, data)
--Scan system for sector data...
end

-------------------------------------------------------
-- Trident under attack toggle
-------------------------------------------------------
function tgft_utils.watchtoggle(_, data)
if tgft_utils.watchdent then
	UnregisterEvent(tgft_utils.MsgNotification, "MSG_NOTIFICATION")
	print("\127ffffffWatch Dent function is now OFF")
else
	RegisterEvent(tgft_utils.MsgNotification, "MSG_NOTIFICATION")
	print("\127ffffffWatch Dent function is now ON")
end
tgft_utils.watchdent = not tgft_utils.watchdent 
end

-------------------------------------------------------
-- Trident under attack function
-------------------------------------------------------
function tgft_utils.MsgNotification(_, data)
if not data then print("No data...") ; return end
if (string.match(data, "Your ship is under attack")) then 
	SendChat("**** "..data.." ****", "GUILD")
	end
end

-------------------------------------------------------
-- Init
-------------------------------------------------------
function tgft_utils.Init()
UnregisterEvent(tgft_utils.Init1, "SECTOR_LOADED")

tgft_utils.passwd = gkini.ReadString("TGFT_Util","Password" ,"None")
local net = gkini.ReadString("TGFT_Util","Enabled" ,0)
if (net == "0") then tgft_utils.Network = false; else tgft_utils.Network = true; end
tgft_utils.username = GetPlayerName(GetCharacterID())
if ((tgft_utils.passwd == "None") or (string.len(tgft_utils.passwd) < 20)) then 
	tgft_utils.passwd = tgft_utils.RandomString(30)
		gkini.WriteString("TGFT_Util", "Password", tgft_utils.passwd)
	if TGFT_DeBug then print("Your Password is:"..tgft_utils.passwd) end
end

print("\127ffffffTGFT Utilities Version "..tgft_utils.version)
tgft_utils.GetServerData("liststations")
RegisterEvent(tgft_utils.Get_Keychain, "KEYADDED") -- Update the data after getting a new key.
RegisterEvent(tgft_utils.Get_Keychain, "KEYREMOVED") -- Update the data after Losing a key.
RegisterEvent(tgft_utils.VerifyDestination, "SECTOR_LOADED")
RegisterEvent(tgft_utils.VerifyDestination, "NAVROUTE_CHANGED")
RegisterEvent(tgft_utils.SectorUpdate, "SHIP_SPAWN_CINEMATIC_FINISHED")
RegisterEvent(tgft_utils.StationUpdate, "ENTERED_STATION")
RegisterEvent(tgft_utils.SawPlayer, "PLAYER_ENTERED_SECTOR")
RegisterEvent(tgft_utils.SawPlayer, "SHIP_SPAWNED")
RegisterEvent(tgft_utils.ServerDataEvent, "TGFT_SERVER_DATA")
RegisterEvent(tgft_utils.MsgNotification, "MSG_NOTIFICATION")
RegisterEvent(tgft_utils.PriceUpdate,"CHAT_MSG_CONFIRMATION")
tgft_utils.Get_Keychain()
end

-------------------------------------------------------
-- Init
-------------------------------------------------------
function tgft_utils.Init1()
	tgft_utils.Timer:SetTimeout(8000,tgft_utils.Init)
end 

-------------------------------------------------------
-- Help
-------------------------------------------------------
function tgft_utils.Help()
tgft_utils.ui:ShowHelp()
end

function tgft_utils.uion()
--tgft_utils.mydlg.mywindow:show()
end
function tgft_utils.uioff()
--tgft_utils.mydlg.mywindow:hide()
end

RegisterUserCommand("tguion",tgft_utils.uion);
RegisterUserCommand("tguioff",tgft_utils.uioff);
RegisterUserCommand("verify",tgft_utils.verify);
RegisterUserCommand("ltest",tgft_utils.BuyUpdate);

-------------------------------------------------------
-- Commands the user can use in quotes
-------------------------------------------------------
RegisterUserCommand("search",tgft_utils.SearchItems);
RegisterUserCommand("botsearch",tgft_utils.SearchBots);
RegisterUserCommand("lowprice",tgft_utils.LookupItemLow);
RegisterUserCommand("highprice",tgft_utils.LookupItemHigh);
RegisterUserCommand("mydent", tgft_utils.FindDent);
RegisterUserCommand("stations",tgft_utils.Stations);
RegisterUserCommand("players",tgft_utils.Lastseen);
RegisterUserCommand("altfinder",tgft_utils.Altfinder);
RegisterUserCommand("lastdata",tgft_utils.LastSeenData);

RegisterUserCommand("idebug", debugtoggle);
RegisterUserCommand("guilditem", tgft_utils.GuildItem);
RegisterUserCommand("lowsystem",tgft_utils.LookupItemLowSystem);
RegisterUserCommand("highsystem",tgft_utils.LookupItemHighSystem);

RegisterUserCommand("autounload",tgft_utils.Unload);
RegisterUserCommand("hostile",tgft_utils.Hostile);
RegisterUserCommand("app",tgft_utils.App);
RegisterUserCommand("turbotoggle",turbotoggle);
RegisterUserCommand("launch",tgft_utils.launch);
RegisterUserCommand("tgft_init",tgft_utils.Init);
RegisterUserCommand("tgft",tgft_utils.Help);

RegisterUserCommand("bindsave",tgft_utils.BindSave);
RegisterUserCommand("alarm",tgft_utils.watchtoggle);
RegisterUserCommand("tgftnet",tgft_utils.nettoggle);

-------------------------------------------------------
-- register events 
-------------------------------------------------------
RegisterEvent(tgft_utils.Init1, "SECTOR_LOADED")
